Learn R Programming

cpa (version 1.0.1)

cpa-package: Confirmatory Path Analysis through the d-sep tests

Description

The package includes functions to test and compare causal models

Arguments

Details

Package: cpa
Type: Package
Version: 1.0.1
Date: 2022-06-04
License: GPL (>= 2)

For usage, see the documentation of the main function 'cpa'

References

Bellino A, Baldantoni D, De Nicola F, Iovieno P, Zaccardelli M, Alfani A. (2015) Compost amendments in agricultural ecosystems: confirmatory path analysis to clarify the effects on soil chemical and biological properties. Journal of Agricultural Science 253,282--295

See Also

ggm

Examples

Run this code
# NOT RUN {
x <- cpa()
# }

Run the code above in your browser using DataLab